@@ -2,8 +2,8 @@ from typing import List
 from threading import Semaphore, Lock
 from multipledispatch import dispatch
 
-from .threads import PlaylistQueueAdder, MusicQueueAdder
-from .musics import SimpleMusic, Playlist
+from rizthme.models.threads import playlist_queue_add, music_queue_add
+from rizthme.models.musics import SimpleMusic, Playlist
 
 
 class MusicQueue(List[SimpleMusic]):
@@ -17,9 +17,9 @@ class MusicQueue(List[SimpleMusic]):
     def add_music(self, music: SimpleMusic):
         # if the message is a valid song
         if music.is_valid(send_message=True):
-            MusicQueueAdder(self, music, self._queue_semaphore, self._is_adding_lock).start()
+            music_queue_add(self, music, self._queue_semaphore, self._is_adding_lock)
 
     @dispatch(Playlist)
     def add_music(self, playlist: Playlist):
         playlist.send("Loading playlist... (this may take a while)")
-        PlaylistQueueAdder(self, playlist, self._queue_semaphore, self._is_adding_lock).start()
+        playlist_queue_add(self, playlist, self._queue_semaphore, self._is_adding_lock)
